imageBuilder property
A builder that wraps the successfully loaded vector graphic widget.
This builder is only called when the vector graphic has been successfully loaded and is ready to be painted. It can be used to apply decorations such as borders or shadows only when the image is available.
Implementation
final VectorGraphicsImageWidget? imageBuilder;